searchData={"items":[{"type":"module","title":"Atex.AtURI","doc":"Struct and helper functions for manipulating `at://` URIs, which identify\nspecific records within the AT Protocol.\n\nATProto spec: https://atproto.com/specs/at-uri-scheme\n\nThis module only supports the restricted URI syntax used for the Lexicon\n`at-uri` type, with no support for query strings or fragments. If/when the\nfull syntax gets widespread use, this module will expand to accomodate them.\n\nBoth URIs using DIDs and handles (\"example.com\") are supported.","ref":"Atex.AtURI.html"},{"type":"function","title":"Atex.AtURI.match?/1","doc":"Check if a string is a valid `at://` URI.","ref":"Atex.AtURI.html#match?/1"},{"type":"function","title":"Examples - Atex.AtURI.match?/1","doc":"iex> Atex.AtURI.match?(\"at://did:plc:44ybard66vv44zksje25o7dz/app.bsky.feed.post/3jwdwj2ctlk26\")\n    true\n\n    iex> Atex.AtURI.match?(\"at://did:web:comet.sh\")\n    true\n\n    iex> Atex.AtURI.match?(\"at://ovyerus.com/sh.comet.v0.feed.track\")\n    true\n\n    iex> Atex.AtURI.match?(\"gobbledy gook\")\n    false","ref":"Atex.AtURI.html#match?/1-examples"},{"type":"function","title":"Atex.AtURI.new/1","doc":"Create a new AtURI struct from a string by matching it against the regex.\n\nReturns `{:ok, aturi}` if a valid `at://` URI is given, otherwise it will return `:error`.","ref":"Atex.AtURI.html#new/1"},{"type":"function","title":"Examples - Atex.AtURI.new/1","doc":"iex> Atex.AtURI.new(\"at://did:plc:44ybard66vv44zksje25o7dz/app.bsky.feed.post/3jwdwj2ctlk26\")\n    {:ok, %Atex.AtURI{\n      rkey: \"3jwdwj2ctlk26\",\n      collection: \"app.bsky.feed.post\",\n      authority: \"did:plc:44ybard66vv44zksje25o7dz\"\n    }}\n\n    iex> Atex.AtURI.new(\"at:invalid/malformed\")\n    :error\n\nPartial URIs pointing to a collection without a record key, or even just a given authority, are also supported:\n\n    iex> Atex.AtURI.new(\"at://ovyerus.com/sh.comet.v0.feed.track\")\n    {:ok, %Atex.AtURI{\n      rkey: nil,\n      collection: \"sh.comet.v0.feed.track\",\n      authority: \"ovyerus.com\"\n    }}\n\n    iex> Atex.AtURI.new(\"at://did:web:comet.sh\")\n    {:ok, %Atex.AtURI{\n      rkey: nil,\n      collection: nil,\n      authority: \"did:web:comet.sh\"\n    }}","ref":"Atex.AtURI.html#new/1-examples"},{"type":"function","title":"Atex.AtURI.new!/1","doc":"The same as `new/1` but raises an `ArgumentError` if an invalid string is given.","ref":"Atex.AtURI.html#new!/1"},{"type":"function","title":"Examples - Atex.AtURI.new!/1","doc":"iex> Atex.AtURI.new!(\"at://did:plc:44ybard66vv44zksje25o7dz/app.bsky.feed.post/3jwdwj2ctlk26\")\n    %Atex.AtURI{\n      rkey: \"3jwdwj2ctlk26\",\n      collection: \"app.bsky.feed.post\",\n      authority: \"did:plc:44ybard66vv44zksje25o7dz\"\n    }\n\n    iex> Atex.AtURI.new!(\"at:invalid/malformed\")\n    ** (ArgumentError) Malformed at:// URI","ref":"Atex.AtURI.html#new!/1-examples"},{"type":"type","title":"Atex.AtURI.t/0","doc":"","ref":"Atex.AtURI.html#t:t/0"},{"type":"function","title":"Atex.AtURI.to_string/1","doc":"Format an `Atex.AtURI` to the canonical string representation.\n\nAlso available via the `String.Chars` protocol.","ref":"Atex.AtURI.html#to_string/1"},{"type":"function","title":"Examples - Atex.AtURI.to_string/1","doc":"iex> aturi = %Atex.AtURI{\n    ...>   rkey: \"3jwdwj2ctlk26\",\n    ...>   collection: \"app.bsky.feed.post\",\n    ...>   authority: \"did:plc:44ybard66vv44zksje25o7dz\"\n    ...> }\n    iex> Atex.AtURI.to_string(aturi)\n    \"at://did:plc:44ybard66vv44zksje25o7dz/app.bsky.feed.post/3jwdwj2ctlk26\"\n\n    iex> aturi = %Atex.AtURI{authority: \"did:web:comet.sh\"}\n    iex> to_string(aturi)\n    \"at://did:web:comet.sh\"","ref":"Atex.AtURI.html#to_string/1-examples"},{"type":"module","title":"Atex.Base32Sortable","doc":"Codec for the base32-sortable encoding.","ref":"Atex.Base32Sortable.html"},{"type":"function","title":"Atex.Base32Sortable.decode/1","doc":"Decode a base32-sortable string to an integer.","ref":"Atex.Base32Sortable.html#decode/1"},{"type":"function","title":"Atex.Base32Sortable.encode/1","doc":"Encode an integer as a base32-sortable string.","ref":"Atex.Base32Sortable.html#encode/1"},{"type":"module","title":"Atex.HTTP","doc":"","ref":"Atex.HTTP.html"},{"type":"function","title":"Atex.HTTP.get/2","doc":"See  Atex.HTTP.Adapter.Req.get/2 .","ref":"Atex.HTTP.html#get/2"},{"type":"function","title":"Atex.HTTP.post/2","doc":"See  Atex.HTTP.Adapter.Req.post/2 .","ref":"Atex.HTTP.html#post/2"},{"type":"behaviour","title":"Atex.HTTP.Adapter","doc":"Behaviour for defining a HTTP client adapter to be used within atex.","ref":"Atex.HTTP.Adapter.html"},{"type":"type","title":"Atex.HTTP.Adapter.error/0","doc":"","ref":"Atex.HTTP.Adapter.html#t:error/0"},{"type":"callback","title":"Atex.HTTP.Adapter.get/2","doc":"","ref":"Atex.HTTP.Adapter.html#c:get/2"},{"type":"callback","title":"Atex.HTTP.Adapter.post/2","doc":"","ref":"Atex.HTTP.Adapter.html#c:post/2"},{"type":"type","title":"Atex.HTTP.Adapter.result/0","doc":"","ref":"Atex.HTTP.Adapter.html#t:result/0"},{"type":"type","title":"Atex.HTTP.Adapter.success/0","doc":"","ref":"Atex.HTTP.Adapter.html#t:success/0"},{"type":"module","title":"Atex.HTTP.Adapter.Req","doc":"`Req` adapter for atex.","ref":"Atex.HTTP.Adapter.Req.html"},{"type":"module","title":"Atex.HTTP.Response","doc":"A generic response struct to be returned by an `Atex.HTTP.Adapter`.","ref":"Atex.HTTP.Response.html"},{"type":"type","title":"Atex.HTTP.Response.t/0","doc":"","ref":"Atex.HTTP.Response.html#t:t/0"},{"type":"module","title":"Atex.IdentityResolver","doc":"","ref":"Atex.IdentityResolver.html"},{"type":"type","title":"Atex.IdentityResolver.options/0","doc":"","ref":"Atex.IdentityResolver.html#t:options/0"},{"type":"function","title":"Atex.IdentityResolver.resolve/2","doc":"","ref":"Atex.IdentityResolver.html#resolve/2"},{"type":"behaviour","title":"Atex.IdentityResolver.Cache","doc":"","ref":"Atex.IdentityResolver.Cache.html"},{"type":"callback","title":"Atex.IdentityResolver.Cache.child_spec/1","doc":"Get the child specification for starting the cache in a supervision tree.","ref":"Atex.IdentityResolver.Cache.html#c:child_spec/1"},{"type":"callback","title":"Atex.IdentityResolver.Cache.delete/1","doc":"Delete an identity in the cache.","ref":"Atex.IdentityResolver.Cache.html#c:delete/1"},{"type":"function","title":"Atex.IdentityResolver.Cache.get/1","doc":"See  Atex.IdentityResolver.Cache.ETS.get/1 .","ref":"Atex.IdentityResolver.Cache.html#get/1"},{"type":"callback","title":"Atex.IdentityResolver.Cache.get/1","doc":"Retrieve an identity from the cache by DID *or* handle.","ref":"Atex.IdentityResolver.Cache.html#c:get/1"},{"type":"callback","title":"Atex.IdentityResolver.Cache.insert/1","doc":"Add a new identity to the cache. Can also be used to update an identity that may already exist.\n\nReturns the input `t:Atex.IdentityResolver.Identity.t/0`.","ref":"Atex.IdentityResolver.Cache.html#c:insert/1"},{"type":"module","title":"Atex.IdentityResolver.Cache.ETS","doc":"","ref":"Atex.IdentityResolver.Cache.ETS.html"},{"type":"function","title":"Atex.IdentityResolver.Cache.ETS.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Atex.IdentityResolver.Cache.ETS.html#child_spec/1"},{"type":"function","title":"Atex.IdentityResolver.Cache.ETS.start_link/1","doc":"","ref":"Atex.IdentityResolver.Cache.ETS.html#start_link/1"},{"type":"module","title":"Atex.IdentityResolver.DID","doc":"","ref":"Atex.IdentityResolver.DID.html"},{"type":"type","title":"Atex.IdentityResolver.DID.resolution_result/0","doc":"","ref":"Atex.IdentityResolver.DID.html#t:resolution_result/0"},{"type":"function","title":"Atex.IdentityResolver.DID.resolve/1","doc":"","ref":"Atex.IdentityResolver.DID.html#resolve/1"},{"type":"module","title":"Atex.IdentityResolver.DIDDocument","doc":"Struct and schema for describing and validating a [DID document](https://github.com/w3c/did-wg/blob/main/did-explainer.md#did-documents).","ref":"Atex.IdentityResolver.DIDDocument.html"},{"type":"function","title":"Atex.IdentityResolver.DIDDocument.from_json/1","doc":"","ref":"Atex.IdentityResolver.DIDDocument.html#from_json/1"},{"type":"function","title":"Atex.IdentityResolver.DIDDocument.get_atproto_handle/1","doc":"Get the associated ATProto handle in the DID document.\n\nATProto dictates that only the first valid handle is to be used, so this\nfollows that rule.\n\n> #### Note {: .info}\n>\n> While DID documents are fairly authoritative, you need to make sure to\n> validate the handle bidirectionally. See\n> `Atex.IdentityResolver.Handle.resolve/2`.","ref":"Atex.IdentityResolver.DIDDocument.html#get_atproto_handle/1"},{"type":"function","title":"Atex.IdentityResolver.DIDDocument.get_schema/1","doc":"","ref":"Atex.IdentityResolver.DIDDocument.html#get_schema/1"},{"type":"function","title":"Atex.IdentityResolver.DIDDocument.new/1","doc":"","ref":"Atex.IdentityResolver.DIDDocument.html#new/1"},{"type":"function","title":"Atex.IdentityResolver.DIDDocument.schema/1","doc":"","ref":"Atex.IdentityResolver.DIDDocument.html#schema/1"},{"type":"function","title":"Atex.IdentityResolver.DIDDocument.schema!/1","doc":"","ref":"Atex.IdentityResolver.DIDDocument.html#schema!/1"},{"type":"type","title":"Atex.IdentityResolver.DIDDocument.service/0","doc":"","ref":"Atex.IdentityResolver.DIDDocument.html#t:service/0"},{"type":"function","title":"Atex.IdentityResolver.DIDDocument.service/1","doc":"","ref":"Atex.IdentityResolver.DIDDocument.html#service/1"},{"type":"function","title":"Atex.IdentityResolver.DIDDocument.service!/1","doc":"","ref":"Atex.IdentityResolver.DIDDocument.html#service!/1"},{"type":"type","title":"Atex.IdentityResolver.DIDDocument.t/0","doc":"","ref":"Atex.IdentityResolver.DIDDocument.html#t:t/0"},{"type":"function","title":"Atex.IdentityResolver.DIDDocument.validate_for_atproto/2","doc":"","ref":"Atex.IdentityResolver.DIDDocument.html#validate_for_atproto/2"},{"type":"type","title":"Atex.IdentityResolver.DIDDocument.verification_method/0","doc":"","ref":"Atex.IdentityResolver.DIDDocument.html#t:verification_method/0"},{"type":"function","title":"Atex.IdentityResolver.DIDDocument.verification_method/1","doc":"","ref":"Atex.IdentityResolver.DIDDocument.html#verification_method/1"},{"type":"function","title":"Atex.IdentityResolver.DIDDocument.verification_method!/1","doc":"","ref":"Atex.IdentityResolver.DIDDocument.html#verification_method!/1"},{"type":"module","title":"Atex.IdentityResolver.Handle","doc":"","ref":"Atex.IdentityResolver.Handle.html"},{"type":"function","title":"Atex.IdentityResolver.Handle.resolve/2","doc":"","ref":"Atex.IdentityResolver.Handle.html#resolve/2"},{"type":"type","title":"Atex.IdentityResolver.Handle.strategy/0","doc":"","ref":"Atex.IdentityResolver.Handle.html#t:strategy/0"},{"type":"module","title":"Atex.IdentityResolver.Identity","doc":"","ref":"Atex.IdentityResolver.Identity.html"},{"type":"type","title":"Atex.IdentityResolver.Identity.did/0","doc":"The controlling DID for an identity.","ref":"Atex.IdentityResolver.Identity.html#t:did/0"},{"type":"type","title":"Atex.IdentityResolver.Identity.document/0","doc":"The resolved DID document for an identity.","ref":"Atex.IdentityResolver.Identity.html#t:document/0"},{"type":"type","title":"Atex.IdentityResolver.Identity.handle/0","doc":"The human-readable handle for an identity. Can be missing.","ref":"Atex.IdentityResolver.Identity.html#t:handle/0"},{"type":"function","title":"Atex.IdentityResolver.Identity.new/3","doc":"","ref":"Atex.IdentityResolver.Identity.html#new/3"},{"type":"type","title":"Atex.IdentityResolver.Identity.t/0","doc":"","ref":"Atex.IdentityResolver.Identity.html#t:t/0"},{"type":"module","title":"Atex.Peri","doc":"Custom validators for Peri, for use within atex.","ref":"Atex.Peri.html"},{"type":"function","title":"Atex.Peri.did/0","doc":"","ref":"Atex.Peri.html#did/0"},{"type":"function","title":"Atex.Peri.uri/0","doc":"","ref":"Atex.Peri.html#uri/0"},{"type":"module","title":"Atex.TID","doc":"Struct and helper functions for dealing with AT Protocol TIDs (Timestamp\nIdentifiers), a 13-character string representation of a 64-bit number\ncomprised of a Unix timestamp (in microsecond precision) and a random \"clock\nidentifier\" to help avoid collisions.\n\nATProto spec: https://atproto.com/specs/tid\n\nTID strings are always 13 characters long. All bits in the 64-bit number are\nencoded, essentially meaning that the string is padded with \"2\" if necessary,\n(the 0th character in the base32-sortable alphabet).","ref":"Atex.TID.html"},{"type":"type","title":"Atex.TID.clock_id/0","doc":"An integer to be used for the lower 10 bits of the TID.","ref":"Atex.TID.html#t:clock_id/0"},{"type":"function","title":"Atex.TID.decode/1","doc":"Decode a TID string into an `Atex.TID` struct, returning an error if it's invalid.","ref":"Atex.TID.html#decode/1"},{"type":"function","title":"Examples - Atex.TID.decode/1","doc":"Syntactically valid TIDs:\n\n    iex> Atex.TID.decode(\"3jzfcijpj2z2a\")\n    {:ok, %Atex.TID{clock_id: 6, timestamp: 1688137381887007}}\n\n    iex> Atex.TID.decode(\"7777777777777\")\n    {:ok, %Atex.TID{clock_id: 165, timestamp: 5811096293381285}}\n\n    iex> Atex.TID.decode(\"3zzzzzzzzzzzz\")\n    {:ok, %Atex.TID{clock_id: 1023, timestamp: 2251799813685247}}\n\n    iex> Atex.TID.decode(\"2222222222222\")\n    {:ok, %Atex.TID{clock_id: 0, timestamp: 0}}\n\nInvalid TIDs:\n\n    # not base32\n    iex> Atex.TID.decode(\"3jzfcijpj2z21\")\n    :error\n    iex> Atex.TID.decode(\"0000000000000\")\n    :error\n\n    # case-sensitive\n    iex> Atex.TID.decode(\"3JZFCIJPJ2Z2A\")\n    :error\n\n    # too long/short\n    iex> Atex.TID.decode(\"3jzfcijpj2z2aa\")\n    :error\n    iex> Atex.TID.decode(\"3jzfcijpj2z2\")\n    :error\n    iex> Atex.TID.decode(\"222\")\n    :error\n\n    # legacy dash syntax *not* supported (TTTT-TTT-TTTT-CC)\n    iex> Atex.TID.decode(\"3jzf-cij-pj2z-2a\")\n    :error\n\n    # high bit can't be set\n    iex> Atex.TID.decode(\"zzzzzzzzzzzzz\")\n    :error\n    iex> Atex.TID.decode(\"kjzfcijpj2z2a\")\n    :error","ref":"Atex.TID.html#decode/1-examples"},{"type":"function","title":"Atex.TID.encode/1","doc":"Encode a TID struct into a string.","ref":"Atex.TID.html#encode/1"},{"type":"function","title":"Examples - Atex.TID.encode/1","doc":"iex> Atex.TID.encode(%Atex.TID{clock_id: 6, timestamp: 1688137381887007})\n    \"3jzfcijpj2z2a\"\n\n    iex> Atex.TID.encode(%Atex.TID{clock_id: 165, timestamp: 5811096293381285})\n    \"7777777777777\"\n\n    iex> Atex.TID.encode(%Atex.TID{clock_id: 1023, timestamp: 2251799813685247})\n    \"3zzzzzzzzzzzz\"\n\n    iex> Atex.TID.encode(%Atex.TID{clock_id: 0, timestamp: 0})\n    \"2222222222222\"","ref":"Atex.TID.html#encode/1-examples"},{"type":"function","title":"Atex.TID.gen_clock_id/0","doc":"Generate a random integer to be used as a `clock_id`.","ref":"Atex.TID.html#gen_clock_id/0"},{"type":"function","title":"Atex.TID.new/2","doc":"Create a new TID from a `DateTime` or an integer representing a Unix timestamp in microseconds.\n\nIf `clock_id` isn't provided, a random one will be generated.","ref":"Atex.TID.html#new/2"},{"type":"function","title":"Atex.TID.now/0","doc":"Returns a TID for the current moment in time, along with a random clock ID.","ref":"Atex.TID.html#now/0"},{"type":"type","title":"Atex.TID.t/0","doc":"","ref":"Atex.TID.html#t:t/0"},{"type":"type","title":"Atex.TID.timestamp/0","doc":"A Unix timestamp representing when the TID was created.","ref":"Atex.TID.html#t:timestamp/0"},{"type":"function","title":"Atex.TID.to_datetime/1","doc":"Convert a TID struct to an instance of `DateTime`.","ref":"Atex.TID.html#to_datetime/1"},{"type":"module","title":"Atex.XRPC","doc":"","ref":"Atex.XRPC.html"},{"type":"function","title":"Atex.XRPC.get/3","doc":"Perform a HTTP GET on a XRPC resource. Called a \"query\" in lexicons.","ref":"Atex.XRPC.html#get/3"},{"type":"function","title":"Atex.XRPC.post/3","doc":"Perform a HTTP POST on a XRPC resource. Called a \"prodecure\" in lexicons.","ref":"Atex.XRPC.html#post/3"},{"type":"function","title":"Atex.XRPC.put_auth/2","doc":"Put an `authorization` header into a keyword list of options to pass to a HTTP client.","ref":"Atex.XRPC.html#put_auth/2"},{"type":"function","title":"Atex.XRPC.unauthed_get/3","doc":"Like `get/3` but is unauthenticated by default.","ref":"Atex.XRPC.html#unauthed_get/3"},{"type":"function","title":"Atex.XRPC.unauthed_post/3","doc":"Like `post/3` but is unauthenticated by default.","ref":"Atex.XRPC.html#unauthed_post/3"},{"type":"module","title":"Atex.XRPC.Client","doc":"Struct to store client information for ATProto XRPC.","ref":"Atex.XRPC.Client.html"},{"type":"function","title":"Atex.XRPC.Client.login/4","doc":"Create a new `Atex.XRPC.Client` by logging in with an `identifier` and\n`password` to fetch an initial pair of access & refresh tokens.\n\nUses `com.atproto.server.createSession` under the hood, so `identifier` can be\neither a handle or a DID.","ref":"Atex.XRPC.Client.html#login/4"},{"type":"function","title":"Examples - Atex.XRPC.Client.login/4","doc":"iex> Atex.XRPC.Client.login(\"https://bsky.social\", \"example.com\", \"password123\")\n    {:ok, %Atex.XRPC.Client{...}}","ref":"Atex.XRPC.Client.html#login/4-examples"},{"type":"function","title":"Atex.XRPC.Client.new/3","doc":"Create a new `Atex.XRPC.Client` from an endpoint, and optionally an\naccess/refresh token.\n\nEndpoint should be the base URL of a PDS, or an AppView in the case of\nunauthenticated requests (like Bluesky's public API), e.g.\n`https://bsky.social`.","ref":"Atex.XRPC.Client.html#new/3"},{"type":"function","title":"Atex.XRPC.Client.refresh/1","doc":"Request a new `refresh_token` for the given client.","ref":"Atex.XRPC.Client.html#refresh/1"},{"type":"type","title":"Atex.XRPC.Client.t/0","doc":"","ref":"Atex.XRPC.Client.html#t:t/0"},{"type":"extras","title":"License","doc":"Copyright 2025 comet.sh\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of\nthis software and associated documentation files (the “Software”), to deal in\nthe Software without restriction, including without limitation the rights to\nuse, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of\nthe Software, and to permit persons to whom the Software is furnished to do so,\nsubject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS\nFOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR\nCOPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER\nIN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN\nCONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"},{"type":"extras","title":"Overview","doc":"# atex\n\nA set of utilities for working with the [AT Protocol](https://atproto.com) in\nElixir.","ref":"readme.html"},{"type":"extras","title":"Current Roadmap (in no particular order) - Overview","doc":"- [x] `at://` parsing and struct\n- [x] TID codecs\n- [x] XRPC client\n- [x] DID & handle resolution service with a cache\n- [ ] Structs with validation for the common lexicons\n  - [ ] Probably codegen for doing this with other lexicons\n- [ ] Extended XRPC client with support for validated inputs/outputs\n- [ ] Oauth stuff","ref":"readme.html#current-roadmap-in-no-particular-order"},{"type":"extras","title":"Installation - Overview","doc":"Get atex from [hex.pm](https://hex.pm) by adding it to your `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:atex, \"~> 0.3\"}\n  ]\nend\n```\n\nDocumentation can be found on HexDocs at https://hexdocs.pm/atex.\n\n---\n\nThis project is licensed under the [MIT License](./LICENSE).","ref":"readme.html#installation"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}